aboutsummaryrefslogtreecommitdiffstats
path: root/csit/scripts/healthcheck/test/health_check.sh
diff options
context:
space:
mode:
Diffstat (limited to 'csit/scripts/healthcheck/test/health_check.sh')
-rwxr-xr-xcsit/scripts/healthcheck/test/health_check.sh30
1 files changed, 19 insertions, 11 deletions
diff --git a/csit/scripts/healthcheck/test/health_check.sh b/csit/scripts/healthcheck/test/health_check.sh
index 05bfeae5..ad23632f 100755
--- a/csit/scripts/healthcheck/test/health_check.sh
+++ b/csit/scripts/healthcheck/test/health_check.sh
@@ -35,34 +35,42 @@ chmod +x docker-compose
checkStatus(){
- for i in {1..60}; do
- res=$($1)
+ for ((i=0; i<$1; i++)); do
+ res=$($2)
echo "$res"
- expect=$2
+ expect=$3
if [ "$res" == "$expect" ]; then
- echo -e "$3 is alive!\n"
+ echo -e "$i sec: $4 is alive!\n"
+ return 0
break;
else
- sleep $i
+ sleep 1
fi
done
+ echo -e "$i sec: $4 is NOT alive!\n"
+ exit -1
}
+
# Healthcheck docker containers
# check SIM1 status
echo "check SIM1 status:"
-checkStatus "curl -skw %{http_code} http://localhost:30001/" "OK200" "SIM1"
+checkStatus 120 "curl -sSkw %{http_code} http://localhost:30001/ " "OK200" "SIM1"
# check SIM2 status
echo "check SIM2 status:"
-checkStatus "curl -skw %{http_code} http://localhost:30003/" "OK200" "SIM2"
+checkStatus 120 "curl -sSkw %{http_code} http://localhost:30003/ " "OK200" "SIM2"
# check SIM3 status
echo "check SIM3 status:"
-checkStatus "curl -skw %{http_code} http://localhost:30005/" "OK200" "SIM3"
+checkStatus 120 "curl -sSkw %{http_code} http://localhost:30005/ " "OK200" "SIM3"
+
+# check PMS status (HTTPS)
+echo "check PMS status (HTTPS):"
+checkStatus 120 "curl -sSkw %{http_code} https://localhost:8433/status " "success200" "PMS (HTTPS)"
-# check PMS status
-echo "check PMS status:"
-checkStatus "curl -skw %{http_code} http://localhost:8081/status" "success200" "PMS"
+# check PMS status (HTTPS)
+echo "check PMS status (HTTPS):"
+checkStatus 120 "curl -sSkw %{http_code} http://localhost:8081/status " "success200" "PMS (HTTP)"
echo "NONRTRIC health check passed."